@@ -38,13 +38,23 @@ class BrowserType(enum.Enum):
 
 
 def get_browser(
-    priority=(BrowserType.CHROME, BrowserType.FIREFOX, BrowserType.SAFARI)
+    priority=(BrowserType.CHROME, BrowserType.FIREFOX, BrowserType.SAFARI),
+    headless: bool = True,
 ) -> webdriver.WebDriver:
+    """Lil' helper function to attempt to get a valid WebDriver"""
+
     def _(browser_name: BrowserType) -> webdriver.WebDriver:
         try:
-            browser = getattr(
-                importlib.import_module(".webdriver", "selenium"),
-                browser_name.value,
+            options = importlib.import_module(
+                ".options", f"selenium.webdriver.{browser_name.value.lower()}"
+            ).Options()
+            options.headless = headless
+            browser = functools.partial(
+                getattr(
+                    importlib.import_module(".webdriver", "selenium"),
+                    browser_name.value,
+                ),
+                options=options,
             )
             browser().close()
         except selenium_exceptions.WebDriverException:
@@ -52,11 +62,12 @@ def get_browser(
         else:
             return browser
 
-    found = functools.reduce(lambda x, y: x or y, map(_, priority))
-    if found is None:
-        # TODO: Download geckodriver and use it
-        raise RuntimeError("Could not find any browser")
-    return found
+    for browser in priority:
+        found = _(browser)
+        if found is not None:
+            return found
+    # TODO: Download geckodriver and use it
+    raise RuntimeError("Could not find any browser")
 
 
 @internal.add_typo_safety
@@ -90,8 +101,33 @@ class BrowserContext:
     _waits: Dict[float, WebDriverWait] = field(default_factory=dict)
 
     def query_selector(self, css_selector: str) -> Element:
+        """Instantly find an element that matches the given CSS selector
+
+        .. note::
+
+            If the element you want to find isn't readily available, you can use
+            :meth:`wait` instead (or :meth:`css`, which combines this with :meth:`wait`).
+
+        Args:
+            css_selector (str): The CSS selector to match
+
+        Returns:
+            Element: The element found by the given CSS selector
+
+        Raises:
+            NoElementException: The element doesn't exist
+
+        """
         return Element(self.driver.find_element(By.CSS_SELECTOR, css_selector))
 
+    def css(self, css_selector: str, wait_up_to: float = 10.0) -> Element:
+        return self.wait(
+            expected_conditions.presence_of_element_located(
+                (By.CSS_SELECTOR, css_selector)
+            ),
+            wait_up_to,
+        )
+
     def query_selector_all(self, css_selector: str) -> List[Element]:
         return list(
             map(Element, self.driver.find_elements(By.CSS_SELECTOR, css_selector))
@@ -140,8 +176,6 @@ class BrowserContext:
 
     # def wait_until  # Recieves a function that returns boolean as parameter. Polls.
 
-    # Aliases
-
 
 @internal.add_typo_safety
 @dataclass
